import config from '@/config'
import storage from '@/utils/storage'
import constant from '@/utils/constant'
import { login, logout, getInfo } from '@/api/login'
import { getToken, setToken, removeToken } from '@/utils/auth'

const baseUrl = config.baseUrl

const user = {
  state: {
    token: getToken(),
    name: storage.get(constant.name),
    avatar: storage.get(constant.avatar),
    roles: storage.get(constant.roles),
    permissions: storage.get(constant.permissions),
    nickName: storage.get(constant.nickName),
    loginIdentity: storage.get(constant.loginIdentity),
	userInfo: storage.get(constant.userInfo),
	userId: storage.get(constant.userId)
  },

  mutations: {
    SET_TOKEN: (state, token) => {
      state.token = token
    },
    SET_NAME: (state, name) => {
      state.name = name
      storage.set(constant.name, name)
    },
    SET_AVATAR: (state, avatar) => {
      state.avatar = avatar
      storage.set(constant.avatar, avatar)
    },
    SET_ROLES: (state, roles) => {
      state.roles = roles
      storage.set(constant.roles, roles)
    },
    SET_PERMISSIONS: (state, permissions) => {
      state.permissions = permissions
      storage.set(constant.permissions, permissions)
    },
	SET_NICKNAME: (state, nickName) => {
	  state.nickName = nickName
	  storage.set(constant.nickName, nickName)
	},
	SET_LOGINIDENTITY: (state, loginIdentity) => {
	  state.loginIdentity = loginIdentity
	  storage.set(constant.loginIdentity, loginIdentity)
	},
	SET_USERINFO: (state, userInfo) => {
	  state.userInfo = userInfo
	  storage.set(constant.userInfo, userInfo)
	},
	SET_USERID: (state, userId) => {
	  state.userId = userId
	  storage.set(constant.userId, userId)
	},
  },

  actions: {
    // 登录
    Login({ commit }, userInfo) {
      // const username = userInfo.username.trim()
      // const password = userInfo.password
      // const code = userInfo.code
      // const uuid = userInfo.uuid
      return new Promise((resolve, reject) => {
        login(userInfo).then(res => {
		  res=res.data
          setToken(res.access_token)
          commit('SET_TOKEN', res.access_token)
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 获取用户信息
    GetInfo({ commit, state }) {
      return new Promise((resolve, reject) => {
        getInfo().then(res => {
          const user = res.data.user
          const roles = res.data.roles
          const permissions = res.data.permissions
          // const avatar = (user == null || user.avatar == "" || user.avatar == null) ? require("@/static/images/profile.png") : user.avatar
          const avatar = require("@/static/images/profile.png")
          const username = (user == null || user.userName == "" || user.userName == null) ? "" : user.userName
          const nickName = (user == null || user.nickName == "" || user.nickName == null) ? "" : user.nickName
          const loginIdentity = (user == null || user.loginIdentity == "" || user.loginIdentity == null) ? "" : user.loginIdentity
          if (roles && roles.length > 0) {
            commit('SET_ROLES', roles)
            commit('SET_PERMISSIONS', permissions)
          } else {
            commit('SET_ROLES', ['ROLE_DEFAULT'])
          }
		  if(user){
			  commit('SET_USERINFO',user)
		  }
		  if(user.userId){
			commit('SET_USERID',user.userId)
		  }
          commit('SET_NAME', username)
          commit('SET_NICKNAME', nickName)
          commit('SET_LOGINIDENTITY', loginIdentity)
          commit('SET_AVATAR', avatar)
          resolve(res)
        }).catch(error => {
          reject(error)
        })
      })
    },

    // 退出系统
    LogOut({ commit, state }) {
      return new Promise((resolve, reject) => {
        logout(state.token).then(() => {
          commit('SET_TOKEN', '')
          commit('SET_ROLES', [])
          commit('SET_PERMISSIONS', [])
          removeToken()
          storage.clean()
          resolve()
        }).catch(error => {
          reject(error)
        })
      })
    }
  }
}

export default user
