package org.dromara.business.domain.bo;

import org.dromara.business.domain.CaseTenantOrganization;
import org.dromara.common.mybatis.core.domain.BaseEntity;
import org.dromara.common.core.validate.AddGroup;
import org.dromara.common.core.validate.EditGroup;
import io.github.linpeilie.annotations.AutoMapper;
import lombok.Data;
import lombok.EqualsAndHashCode;
import jakarta.validation.constraints.*;
import org.dromara.system.domain.vo.SysOssUploadVo;

import java.util.List;

/**
 * 合作组织业务对象 case_tenant_organization
 *
 * @author wuzhigang
 * @date 2023-12-19
 */
@Data
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = CaseTenantOrganization.class, reverseConvertGenerate = false)
public class CaseTenantOrganizationBo extends BaseEntity {

    /**
     * 主键
     */
    @NotNull(message = "主键不能为空", groups = { EditGroup.class })
    private Long id;

    /**
     * 组织名称
     */
    @NotBlank(message = "组织名称不能为空", groups = { AddGroup.class })
    private String organizationName;

    /**
     * 组织分类 0学会 1协会 2基金会
     */
    @NotBlank(message = "组织分类 0学会 1协会 2基金会不能为空", groups = { AddGroup.class})
    private String organizationType;

    /**
     * 省编码
     */
    private String provinceCode;

    /**
     * 省名称
     */
    private String provinceName;

    /**
     * 市编码
     */
    private String cityCode;

    /**
     * 市名称
     */
    private String cityName;

    /**
     * 组织logo OSS信息
     */
    private List<SysOssUploadVo> organizationLogo;

    /**
     * 状态 0启用,1禁用
     */
    @NotBlank(message = "状态 0启用,1禁用不能为空", groups = { AddGroup.class})
    private String status;


}
