package org.dromara.system.domain.bo;

import org.dromara.system.domain.CaseMessage;
import org.dromara.common.mybatis.core.domain.BaseEntity;
import org.dromara.common.core.validate.AddGroup;
import org.dromara.common.core.validate.EditGroup;
import io.github.linpeilie.annotations.AutoMapper;
import lombok.Data;
import lombok.EqualsAndHashCode;
import jakarta.validation.constraints.*;

/**
 * 消息中心业务对象 case_message
 *
 * @author wuzhigang
 * @date 2023-12-06
 */
@Data
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = CaseMessage.class, reverseConvertGenerate = false)
public class CaseMessageBo extends BaseEntity {

    /**
     * 主键
     */
    @NotNull(message = "主键不能为空", groups = { EditGroup.class })
    private Long id;

    /**
     * 消息分类 0病例 1医生志愿者绑定
     */
    @NotBlank(message = "消息分类 0病例 1医生志愿者绑定", groups = { AddGroup.class, EditGroup.class })
    private String messageType;

    /**
     * 消息内容
     */
    @NotBlank(message = "消息内容", groups = { AddGroup.class, EditGroup.class })
    private String messageContent;

    /**
     * 业务主键
     */
    private Long businessId;

    /**
     * 用户ID
     */
    @NotNull(message = "用户ID", groups = { AddGroup.class, EditGroup.class })
    private Long userId;

    /**
     * 业务状态 0审核通过 1审核未通过 2已美化 3绑定 4解绑 5已点评 6解析申请通过 7解析申请未通过 8解析完成
     */
    private String businessStatus;


}

