package org.dromara.system.domain.bo;

import com.alibaba.excel.annotation.ExcelProperty;
import io.github.linpeilie.annotations.AutoMapper;
import jakarta.validation.constraints.NotBlank;
import jakarta.validation.constraints.NotNull;
import jakarta.validation.constraints.Pattern;
import jakarta.validation.constraints.Size;
import lombok.Data;
import lombok.EqualsAndHashCode;
import org.dromara.common.core.validate.AddGroup;
import org.dromara.common.core.validate.EditGroup;
import org.dromara.common.mybatis.core.domain.BaseEntity;
import org.dromara.system.domain.SysTenant;
import org.dromara.system.domain.vo.SysOssUploadVo;

import java.util.Arrays;
import java.util.List;

/**
 * 租户业务对象 sys_tenant
 *
 * @author Michelle.Chung
 */

@Data
@EqualsAndHashCode(callSuper = true)
@AutoMapper(target = SysTenant.class, reverseConvertGenerate = false)
public class SysTenantBo extends BaseEntity {

    /**
     * id
     */
    @NotNull(message = "id不能为空", groups = {EditGroup.class})
    private Long id;

    /**
     * 租户编号
     */
    private String tenantId;

    /**
     * 联系人
     */
    @NotBlank(message = "联系人不能为空", groups = {AddGroup.class, EditGroup.class})
    private String contactUserName;

    /**
     * 联系电话
     */
    @NotBlank(message = "联系电话不能为空", groups = {AddGroup.class, EditGroup.class})
    private String contactPhone;

    /**
     * 租户名称名称
     */
    @NotBlank(message = "租户名称不能为空", groups = {AddGroup.class, EditGroup.class})
    @Size(max = 30, message = "租户名称不能超过30")
    private String companyName;

    /**
     * 备注
     */
    private String remark;

    /**
     * 租户套餐编号
     */
    @NotNull(message = "租户套餐不能为空", groups = {AddGroup.class})
    private Long packageId;

    /**
     * 用户数量（-1不限制）
     */
    private Long accountCount;

    /**
     * 租户状态（0正常 1停用）
     */
    private String status;

    /**
     * 合作组织
     */
    @Size(max = 30, message = "租户名称不能超过30")
    private String tenantOrganization;

    /**
     * 合作组织名称
     */
    private String organizationName;

    /**
     * 注册（0开通 1关闭）
     */
    private String register;

    /**
     * 协议文件列表
     */
    private List<SysOssUploadVo> agreementFileList;

    /**
     * 学会管理端访问地址
     */
    private String pcAccessPath;

    /**
     * 移动端访问地址
     */
    private String appAccessPath;

    /**
     * 授权登录身份 0-医生 0,1-医生，志愿者 0,1,2-医生，志愿者，专家
     */
    private String authorizedLogin;

    /**
     * 病例需要审核 0是 1否
     */
    private String caseReview;

    /**
     * 病例需要点评 0是 1否
     */
    private String caseComment;

    /**
     * 病例点评分配 0手动分配  1自动分配
     */
    private String caseCommentDistribution;

    /**
     * 主题色
     */
    private String themeColor;

    /**
     * 病例是否需要评分 0是 1否
     */
    private String caseCommentScore;

    /**
     * 水印内容
     */
    private String waterMarkText;

}
