package org.dromara.system.domain.vo;

import java.util.Date;
import com.alibaba.excel.annotation.ExcelIgnoreUnannotated;
import com.alibaba.excel.annotation.ExcelProperty;
import org.dromara.common.excel.annotation.ExcelDictFormat;
import org.dromara.common.excel.convert.ExcelDictConvert;
import org.dromara.system.domain.SysTenant;
import io.github.linpeilie.annotations.AutoMapper;
import lombok.Data;

import java.io.Serial;
import java.io.Serializable;
import java.util.List;


/**
 * 租户视图对象 sys_tenant
 *
 * @author Michelle.Chung
 */
@Data
@ExcelIgnoreUnannotated
@AutoMapper(target = SysTenant.class)
public class SysTenantVo implements Serializable {

    @Serial
    private static final long serialVersionUID = 1L;

    /**
     * id
     */
    @ExcelProperty(value = "id")
    private Long id;

    /**
     * 租户编号
     */
    @ExcelProperty(value = "租户编号")
    private String tenantId;

    /**
     * 联系人
     */
    @ExcelProperty(value = "联系人")
    private String contactUserName;

    /**
     * 联系电话
     */
    @ExcelProperty(value = "联系电话")
    private String contactPhone;

    /**
     * 租户名称
     */
    @ExcelProperty(value = "租户名称")
    private String companyName;

    /**
     * 备注
     */
    @ExcelProperty(value = "备注")
    private String remark;

    /**
     * 租户套餐编号
     */
    @ExcelProperty(value = "租户套餐编号")
    private Long packageId;

    /**
     * 用户数量（-1不限制）
     */
    @ExcelProperty(value = "用户数量")
    private Long accountCount;

    /**
     * 租户状态（0正常 1停用）
     */
    @ExcelProperty(value = "租户状态", converter = ExcelDictConvert.class)
    @ExcelDictFormat(readConverterExp = "0=正常,1=停用")
    private String status;

    /**
     * 合作组织ID
     */
    private String tenantOrganization;

    /**
     * 合作组织名称
     */
    @ExcelProperty(value = "合作组织")
    private String organizationName;

    /**
     * 注册（0开通 1关闭）
     */
    @ExcelProperty(value = "注册", converter = ExcelDictConvert.class)
    @ExcelDictFormat(readConverterExp = "0=开通,1=关闭")
    private String register;

    /**
     * 协议文件
     */
    @ExcelProperty(value = "协议文件")
    private String agreementFileUrl;

    /**
     * 协议文件列表
     */
    private List<SysOssUploadVo> agreementFileList;

    /**
     * 学会管理端访问地址
     */
    @ExcelProperty(value = "学会管理端访问地址")
    private String pcAccessPath;

    /**
     * 移动端访问地址
     */
    @ExcelProperty(value = "移动端访问地址")
    private String appAccessPath;

    /**
     * 授权登录身份
     */
    private String authorizedLogin;

    /**
     * 租户用户数量
     */
    private Long userNumber;

    /**
     * 租户病例数量
     */
    private Long caseNumber;

    /**
     * 病例需要审核 0是 1否
     */
    private String caseReview;

    /**
     * 病例需要点评 0是 1否
     */
    private String caseComment;

    /**
     * 病例点评分配 0手动分配  1自动分配
     */
    private String caseCommentDistribution;

    /**
     * 主题色
     */
    private String themeColor;

    /**
     * logo字符串
     */
    private String organizationLogoStr;

    /**
     * 组织logo OSS信息
     */
    private List<SysOssUploadVo> organizationLogo;

    /**
     * 病例是否需要评分 0是 1否
     */
    private String caseCommentScore;

    /**
     * 水印内容
     */
    private String waterMarkText;

}
