package org.dromara.system.service;

import org.dromara.system.domain.SysDoctorVolunteer;
import org.dromara.system.domain.SysUser;
import org.dromara.system.domain.vo.SysDoctorVolunteerVo;
import org.dromara.system.domain.bo.SysDoctorVolunteerBo;
import org.dromara.common.mybatis.core.page.TableDataInfo;
import org.dromara.common.mybatis.core.page.PageQuery;

import java.util.Collection;
import java.util.List;

/**
 * 医生志愿者关联Service接口
 *
 * @author wuzhigang
 * @date 2023-12-21
 */
public interface ISysDoctorVolunteerService {

    /**
     * 查询医生志愿者关联
     */
    SysDoctorVolunteerVo queryById(Long id);

    /**
     * 查询医生志愿者关联列表
     */
    TableDataInfo<SysDoctorVolunteerVo> queryPageList(SysDoctorVolunteerBo bo, PageQuery pageQuery);

    /**
     * 查询医生志愿者关联列表
     */
    List<SysDoctorVolunteerVo> queryList(SysDoctorVolunteerBo bo);

    /**
     * 新增医生志愿者关联
     */
    Boolean insertByBo(SysDoctorVolunteerBo bo);

    /**
     * 修改医生志愿者关联
     */
    Boolean updateByBo(SysDoctorVolunteerBo bo);

    /**
     * 校验并批量删除医生志愿者关联信息
     */
    Boolean deleteWithValidByIds(Collection<Long> ids, Boolean isValid);

    /**
     * 医生绑定志愿者
     *
     * @param bo
     * @return
     */
    SysUser bindVolunteer(SysDoctorVolunteerBo bo);

    /**
     * 根据医生userId获取绑定志愿者列表
     *
     * @param userId
     * @return
     */
    List<SysDoctorVolunteerVo> volunteerList(Long userId);

    /**
     * 根据志愿者userId获取绑定医生列表
     *
     * @param userId 志愿者ID
     * @return
     */
    List<SysDoctorVolunteerVo> doctorList(Long userId);

    /**
     * 志愿者绑定医生
     *
     * @param bo
     * @return
     */
    SysUser bindDoctor(SysDoctorVolunteerBo bo);
}
